# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['baudelaire']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.8,<9.0.0',
 'confuk>=0.6.3,<0.7.0',
 'pillow>=11.1.0,<12.0.0',
 'rich>=13.9.4,<14.0.0']

entry_points = \
{'console_scripts': ['baudelaire = baudelaire:main']}

setup_kwargs = {
    'name': 'baudelaire',
    'version': '0.1.0',
    'description': 'Take a poem and make it an Instagram post',
    'long_description': '<p align="center">\n  <img src="static/logo.png" alt="logo" width="200" style="display: block;margin-left: auto;margin-right: auto;"/>\n</p>\n</br>\nCreate Instagram posts from your plaintext poetry in seconds.\n\n## Installation\n\n```bash\npip install baudelaire\n```\n\n## Usage\n\n```bash\nbaudelaire "<plaintext-input>" -o "<output-directory>" -c "<config>"\n```\n\nFor example:\n\n```bash\nbaudelaire -o "outputs" "$(cat "poem.txt")"\n```\n\n> [!note]\n> The input is expected to be a plaintext poem, so you can write the contents directly in the command line or `cat` them from a plaintext file.\n\nThe text will be written to the specified output directory as `poem_part-*.png` files. There is a default configuration file which is distributed as a part of the package.\n\nYou can give it a try by using Dylan Thomas\' _Do not go gentle into that good night_:\n\n```bash\nbaudelaire -o "outputs" "$(cat "tests/rage.txt")"\n```\n\n## Configuration\n\nThe default config is available in the repository under `config/default.yaml`. Check out the comments to understand what each configuration option does.\n\n> [!note]\n> If you change the font you might need to tweak other parameters like the number of lines per board. It\'s recommended to create a separate config per template.\n',
    'author': 'Chris Czarnecki',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



import click
import confuk
from PIL import Image, ImageDraw, ImageFont
from pathlib import Path
from rich.console import Console
import textwrap
import os
from dataclasses import dataclass, field
from typing import *


@dataclass
class Config:
    output_dir: Path
    template_path: Path
    font_path: Path
    font_size: int = 50
    max_chars_per_line: int = 30
    max_lines: int = 10
    text_color: str = "black"
    text_position: Tuple[int, int | None] = (100, None)
    multiline_spacing: int = 10


def create_instagram_poem_images(poem: str,
                                 config: Config):
    console = Console()
    os.makedirs(config.output_dir, exist_ok=True)

    # Preserve line breaks while wrapping text
    lines = []
    for paragraph in poem.split("\n"):
        if "<break>" in paragraph:
            lines.append("<break>")
        else:
            lines.extend(textwrap.wrap(paragraph, width=config.max_chars_per_line) if paragraph else [""])
    
    # Split text into chunks, respecting explicit breaks
    chunks = []
    chunk = []
    for line in lines:
        if line == "<break>" or len(chunk) >= config.max_lines:
            if chunk:
                chunks.append("\n".join(chunk))
                chunk = []
        if line != "<break>":
            chunk.append(line)
    if chunk:
        chunks.append("\n".join(chunk))
    
    images = []
    for i, chunk in enumerate(chunks):
        # Load template
        img = Image.open(config.template_path).convert("RGBA")
        draw = ImageDraw.Draw(img)
        font = ImageFont.truetype(str(config.font_path), config.font_size)
        
        # Define text position (centrally aligned vertically)
        text_x, maybe_text_y = config.text_position
        _, img_height = img.size
        text_bbox = draw.textbbox((0, 0), chunk, font=font, spacing=config.multiline_spacing)
        text_height = text_bbox[3] - text_bbox[1]  # Height is (bottom - top)

        if maybe_text_y is not None:
            text_y = maybe_text_y  # Explicit position
        else:
            text_y = (img_height - text_height) // 2  # Center vertically

        # Draw text
        draw.multiline_text((text_x, text_y), chunk, fill=config.text_color, font=font, spacing=config.multiline_spacing)
        
        # Save output
        output_path = config.output_dir / f"poem_part_{i + 1}.png"
        img.save(output_path)
        images.append(str(output_path))

    console.print(f"Saved {len(images)} images in {config.output_dir}")
    return images


def _main(input_: str,
          output_dir: Path,
          config_path: Path = Path(__file__).parent.parent / "config/default.yaml"):

    config = confuk.parse_config(config_path, "omegaconf")
    cfg = Config(
        output_dir,
        **config
    )
    create_instagram_poem_images(input_, cfg)


@click.command()
@click.argument('input-poem',
                type=str)
@click.option('-o', '--output-dir',
              type=click.Path(exists=False, path_type=Path),
              help="Output directory where image files will be written")
@click.option('-c', '--config-path',
              type=click.Path(exists=True, path_type=Path),
              help="Path to the config file")
def main(input_poem, output_dir, config_path):
    _main(input_poem, output_dir, config_path or Path(__file__).parent.parent / "config/default.yaml")


if __name__ == "__main__":
    main()
